@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::CheckPrereqsIndexed;
 # ABSTRACT: prevent a release if you have prereqs not found on CPAN
-$Dist::Zilla::Plugin::CheckPrereqsIndexed::VERSION = '0.015';
+$Dist::Zilla::Plugin::CheckPrereqsIndexed::VERSION = '0.016';
 use 5.10.0; # //
 use Moose;
 
@@ -14,9 +14,10 @@ use Moose;
 #pod
 #pod If any are unknown, it will prompt the user to continue or abort.
 #pod
-#pod At present, CheckPrereqsIndexed queries CPANIDX, but this behavior is likely to
-#pod change or become pluggable in the future.  In the meantime, this makes
-#pod releasing while offline impossible... but it was anyway, right?
+#pod Previously, CheckPrereqsIndexed queried CPANIDX, but it now queries 
+#pod cpanmetadb. This behavior may change again in the future, or it may become
+#pod pluggable.  In the meantime, this makes releasing while offline impossible...
+#pod but it was anyway, right?
 #pod
 #pod =cut
 
@@ -149,7 +150,7 @@ Dist::Zilla::Plugin::CheckPrereqsIndexed - prevent a release if you have prereqs
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 OVERVIEW
 
@@ -161,9 +162,10 @@ index to ensure that they're all real, installable packages.
 
 If any are unknown, it will prompt the user to continue or abort.
 
-At present, CheckPrereqsIndexed queries CPANIDX, but this behavior is likely to
-change or become pluggable in the future.  In the meantime, this makes
-releasing while offline impossible... but it was anyway, right?
+Previously, CheckPrereqsIndexed queried CPANIDX, but it now queries 
+cpanmetadb. This behavior may change again in the future, or it may become
+pluggable.  In the meantime, this makes releasing while offline impossible...
+but it was anyway, right?
 
 =head1 ATTRIBUTES
 
@@ -178,6 +180,42 @@ distributed in some other way).
 
 Ricardo Signes <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Christopher J. Madsen Dave Rolsky David Golden Karen Etheridge Olivier Mengué Piers Cawley Sébastien Deseille
+
+=over 4
+
+=item *
+
+Christopher J. Madsen <perl@cjmweb.net>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Olivier Mengué <dolmen@cpan.org>
+
+=item *
+
+Piers Cawley <pdcawley@bofh.org.uk>
+
+=item *
+
+Sébastien Deseille <sebastien.deseille@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 by Ricardo Signes.
